@@ -2,7 +2,7 @@
 #' @description Imports multiple files into a list, concatenates them into a single
 #' table, and adds an `fName` variable. The function automatically handles type
 #' harmonization when different file types are mixed and supports various formats
-#' including CSV, Excel, RDS, Parquet, Feather, and QS files.
+#' including CSV, Excel, and RDS files.
 #'
 #' The files can be selected either by giving a file list (character vector), or
 #' by specifying a pattern. The function also supports column renaming and file
@@ -58,13 +58,10 @@
 #' result <- importAll(path = test_path, pattern = "\\.csv$", importFunction = custom_import)
 #' print(result)
 #'
-#' @importFrom openxlsx read.xlsx
+#' @importFrom readxl read_excel
 #' @importFrom data.table fread setnames as.data.table
-#' @importFrom arrow read_parquet read_feather
 #' @importFrom dplyr mutate filter
-#' @importFrom stringr str_detect str_extract
 #' @importFrom tibble tribble
-#' @importFrom qs qread
 #' @export
 importAll <- function(
 		path = "."
@@ -76,7 +73,6 @@ importAll <- function(
 		, renameTable = data.frame(oldName = character(), newName = character())
 		, excludePattern = NULL
 ){
-
 	is_absolute_path <- function(path) {
 		if (length(path) == 0) return(FALSE)
 		# R.utils function
@@ -112,7 +108,7 @@ importAll <- function(
 		} # list file paths : either with pattern, or with fileList => filePaths
 		if(!is.null(excludePattern)){
 			filePaths <- filePaths %>%
-				mutate(toExclude = str_detect(locPath, excludePattern)) %>%
+				mutate(toExclude = grepl(excludePattern, locPath)) %>%
 				filter(!toExclude)
 		} # exclude files matching a pattern
 		files_exist <- file.exists(filePaths$fulPath)
@@ -133,12 +129,9 @@ importAll <- function(
 			filePaths[, ext := gsub(".*\\.", "", locPath)]
 			importFunsList <- tribble(
 				~ext       , ~fun
-				, "xlsx"   , function(x) as.data.table(openxlsx::read.xlsx(x))
+				, "xlsx"   , function(x) as.data.table(readxl::read_excel(x))
 				, "csv"    , fread
 				, "rds"    , readRDS
-				, "parquet", read_parquet
-				, "feather", read_feather
-				, "qs", qs::qread
 			) %>%
 				as.data.table
 
