@@ -22,8 +22,6 @@
 #'
 #' @return A data.table containing the joined table.
 #' @importFrom tibble rowid_to_column rownames_to_column
-#' @importFrom tidyr replace_na
-#' @importFrom stringr str_remove
 #' @rawNamespace import(dplyr, except = c(first, last, between))
 #' @export
 #'
@@ -75,7 +73,10 @@ left_join_checks <- function(
 			xMerge
 			, yMerge
 			, ...
-		) %>% replace_na(list(tmp_inX = 0, tmp_inY = 0))
+		) %>% mutate(
+		tmp_inX = coalesce(tmp_inX, 0),
+		tmp_inY = coalesce(tmp_inY, 0)
+	)
 	} # merge
 	{
 		fnTmr$add("chk_preserved_x")
@@ -91,7 +92,7 @@ left_join_checks <- function(
 		joinMatch <- expand.grid(tmp_inX = 0:1, tmp_inY = 0:1) %>%
 			left_join(joinMatch_prep) %>%
 			suppressMessages %>%
-			replace_na(list(n=0))
+			mutate(n = coalesce(n, 0))
 		chk_yNotFound <- joinMatch %>% filter(!tmp_inY) %>% pull(n) %>% sum
 		chk_xAllMatch <- chk_yNotFound == 0
 		fnTmr$add("counting problems")
@@ -99,20 +100,20 @@ left_join_checks <- function(
 			unlist %>%
 			data.frame(value = .) %>%
 			rownames_to_column("check") %>%
-			mutate(key = str_remove(check, "^chk_|^req_"))
+			mutate(key = sub("^chk_|^req_", "", check))
 
 		reqsTable <- mget(ls(pattern = "^req_")) %>%
 			unlist %>%
 			data.frame(req = .) %>%
 			rownames_to_column("check") %>%
 			mutate(req = req %>% as.numeric) %>%
-			mutate(key = str_remove(check, "^chk_|^req_"))
+			mutate(key = sub("^chk_|^req_", "", check))
 
 		checksTable <- full_join(valuesTable, reqsTable, by = "key") %>%
 			mutate(is_problem = value != req) %>%
 			select(key, value, req, is_problem) %>%
 			mutate(is_problem = is_problem %>% as.numeric) %>%
-			replace_na(list(is_problem = 0)) %>%
+			mutate(is_problem = coalesce(is_problem, 0)) %>%
 			arrange(is_problem %>% desc, req %>% desc)
 	} # checks
 
